@@ -1,29 +1,28 @@
 #' Calculate Densities
 #'
-#' @param x RasterStack with realizations
-#' @param y RasterStack with shares
+#' @param x SpatRaster with realizations
+#' @param y SpatRaster with shares
 #' @param window_size size of a local window
 #'
 #' @return a list of data.frames
 #' @keywords internal
 #'
 #' @examples
-#' library(raster)
+#' library(terra)
+#' race_raster = rast(system.file("extdata/race_raster.tif", package = "raceland"))
 #' real_rasters = create_realizations(race_raster, n = 5)
 #' plot(real_rasters)
 #' d = raceland:::calculate_densities(real_rasters, race_raster, window_size = 10)
 #'
 calculate_densities = function(x, y, window_size){
-  if (!(methods::is(x, "RasterStack") || methods::is(x, "RasterBrick"))){
-    stop("x needs to be either RasterStack or RasterBrick", call. = FALSE)
-  }
-  if (!(methods::is(y, "RasterStack") || methods::is(y, "RasterBrick"))){
-    stop("y needs to be either RasterStack or RasterBrick", call. = FALSE)
-  }
+  is_raster_x = check_is_raster(x)
+  is_raster_y = check_is_raster(y)
+  x = check_input(x, is_raster_x)
+  y = check_input(y, is_raster_y)
   out = if (requireNamespace("pbapply", quietly = TRUE)){
-      pbapply::pblapply(raster::as.list(x), calculate_density, y = y, window_size = window_size)
+      pbapply::pblapply(terra::as.list(x), calculate_density, y = y, window_size = window_size)
   } else {
-      lapply(raster::as.list(x), calculate_density, y = y, window_size = window_size)
+      lapply(terra::as.list(x), calculate_density, y = y, window_size = window_size)
   }
   return(out)
 }
@@ -33,9 +32,9 @@ calculate_densities = function(x, y, window_size){
 # b = calculate_density(real_raster, perc_raster, window_size = 10)
 calculate_density = function(x, y, window_size){
   # x = cats; y = s; size = 2
-  x_areas = motifel_areas(x = raster::as.matrix(x[[1]]), size = window_size)
+  x_areas = motifel_areas(x = terra::as.matrix(x[[1]], wide = TRUE), size = window_size)
 
-  y_prep = lapply(raster::as.list(y), raster::as.matrix)
+  y_prep = lapply(terra::as.list(y), terra::as.matrix, wide = TRUE)
 
   y_sums = do.call(cbind, lapply(y_prep, motifel_sums, size = window_size))
 
